Learn R Programming

ggenealogy (version 0.2.0)

getDescendants: Returns a list of the descendants of a particular variety (if they exist)

Description

This function returns a list of the descendants of the inputted variety within and including a given number of generations

Usage

getDescendants(v1, geneal, gen = 3)

Arguments

v1
the label of the variety/vertex of interest (in character string format)
geneal
the full genealogy (in data frame format)
gen
the number of generations back to include as descendants

Examples

Run this code
data(sbGeneal)
getChild("Essex", sbGeneal)
getDescendants("Essex", sbGeneal, 1)
getDescendants("Essex", sbGeneal, 3)

Run the code above in your browser using DataLab