Learn R Programming

ggenealogy (version 0.2.0)

isChild: Determine if a variety is a child of another

Description

Returns a boolean variable for whether the first variety is a child of the second variety

Usage

isChild(child, parent, geneal)

Arguments

child
possible child variety
parent
possible parent variety
geneal
the full genealogy (in data frame format)

Examples

Run this code
data(sbGeneal)
isChild("Essex", "Young", sbGeneal)
isChild("Young", "Essex", sbGeneal)

Run the code above in your browser using DataLab